@@ -18,15 +18,17 @@
 #ifndef _KDIRWATCH_H
 #define _KDIRWATCH_H
 
-#include <QtCore/QDateTime>
-#include <QtCore/QObject>
-#include <QtCore/QString>
+#include <QDateTime>
+#include <QObject>
+#include <QString>
 
 #include <kcoreaddons_export.h>
 
 class KDirWatchPrivate;
 
 /**
+ * @class KDirWatch kdirwatch.h KDirWatch
+ *
  * @short Class for watching directory and file changes.
  *
  * Watch directories and files for changes.
@@ -82,9 +84,9 @@ public:
      *
      * Scanning begins immediately when a dir/file watch
      * is added.
-     * @param parent the parent of the QObject (or 0 for parent-less KDataTools)
+     * @param parent the parent of the QObject (or @c nullptr for parent-less KDataTools)
      */
-    KDirWatch(QObject *parent = 0);
+    explicit KDirWatch(QObject *parent = nullptr);
 
     /**
      * Destructor.
@@ -154,7 +156,7 @@ public:
      *
      * @param path the path to skip
      * @return true if the @p path is being watched, otherwise false
-     * @see restartDirScanning()
+     * @see restartDirScan()
      */
     bool stopDirScan(const QString &path);
 
@@ -169,7 +171,7 @@ public:
      *
      * @param path the path to restart scanning
      * @return true if the @p path is being watched, otherwise false
-     * @see stopDirScanning()
+     * @see stopDirScan()
      */
     bool restartDirScan(const QString &path);
 
@@ -184,7 +186,7 @@ public:
      * empty. First call should be called with @p false or else all
      * directories
      * in list will be notified.
-     * @param skippedToo if true, the skipped directoris (scanning of which was
+     * @param skippedToo if true, the skipped directories (scanning of which was
      * stopped with stopDirScan() ) will be reset and notified
      * for change. Otherwise, stopped directories will continue to be
      * unnotified.
@@ -212,7 +214,7 @@ public:
      */
     bool contains(const QString &path) const;
 
-    void deleteQFSWatcher();
+    void deleteQFSWatcher(); // KF6 TODO: remove from public API
 
     /**
      * Dump statistic information about the KDirWatch::self() instance.
